@@ -116,7 +116,7 @@ bool KXSConfigDialog::create()
     xmlFile = XSCREENSAVER_CONFIG_DIR;
 #endif
 
-    xmlFile += "/" + mExeName + ".xml";
+    xmlFile += '/' + mExeName + ".xml";
     if ( QFile::exists( xmlFile ) ) {
 	// We can use the xscreensaver xml config files.
 	KXSXml xmlParser(controlLayout);
@@ -124,10 +124,14 @@ bool KXSConfigDialog::create()
 	mConfigItemList = xmlParser.items();
 	QWidget *spacer = new QWidget(controlLayout);
 	controlLayout->setStretchFactor(spacer, 1 );
+	QString name = xmlParser.name();
+	setPlainCaption(i18n("Setup %1", i18nc("@item screen saver name", name.toUtf8())));
 	QString descr = xmlParser.description();
 	if ( !descr.isEmpty() ) {
+	    // NOTE: Simplification must be same as in PO template creation script.
 	    descr = descr.replace('\n', ' ').simplified();
-	    QLabel *l = new QLabel( i18n( descr.toUtf8() ), main );
+	    // NOTE: Contexts has to match with that extracted by the PO template creation script.
+	    QLabel *l = new QLabel( i18nc( "@info screen saver description", descr.toUtf8() ), main );
 	    l->setWordWrap( 1 );
 	    topLayout->addWidget( l );
 	}
@@ -187,6 +191,7 @@ bool KXSConfigDialog::create()
         QPalette palette;
         palette.setColor(mPreview->backgroundRole(), Qt::black);
         mPreview->setPalette(palette);
+	mPreview->setAutoFillBackground(true);
     }
 
     layout->addWidget(mPreview);
@@ -349,6 +354,7 @@ int main(int argc, char *argv[])
   KCmdLineArgs::addCmdLineOptions(options);
 
   KApplication app;
+  KGlobal::locale()->insertCatalog("kxsconfig");
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
   if(args->count()==0)
