@@ -29,7 +29,7 @@ void fixed_size(QWidget *w) {
 KConfig *klock_config()
 {
     QString name( kapp->argv()[0] );
-    int slash = name.findRev( '/' );
+    int slash = name.lastIndexOf( '/' );
     if ( slash )
 	name = name.mid( slash+1 );
 
