@@ -21,6 +21,9 @@
 */
 
 #include "AboveButton.h"
+//Added by qt3to4:
+#include <QPixmap>
+#include <QMouseEvent>
 
 namespace RiscOS
 {
